PALM-meteo: palmmeteo.plugins.ImportPluginMixin Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo.plugins.ImportPluginMixin Class Reference
Inheritance diagram for palmmeteo.plugins.ImportPluginMixin:
[legend]
Collaboration diagram for palmmeteo.plugins.ImportPluginMixin:
[legend]

## Public Member Functions
def | import_data (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
def | __init__ (self, *args, **kwargs)
def | check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
def | __new__ (cls, name, bases, dct)

## Additional Inherited Members
Public Attributes inherited from palmmeteo.plugins.Plugin
| cfg
| rt

## Detailed Description

    Base class mixin for plugins importing data.
    Registers 'import_data' method as a handler for event 'import_data'.

    Abstract methods required to be implemented by derived classes:
        import_data

## Member Function Documentation

## ◆ import_data()

def palmmeteo.plugins.ImportPluginMixin.import_data | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented in palmmeteo_stdplugins.aladin.AladinRadPlugin, palmmeteo_stdplugins.meteo.SomeMeteoPlugin, palmmeteo_stdplugins.meteo.EmisPlugin, palmmeteo_stdplugins.wrf.WRFRadPlugin, palmmeteo_stdplugins.aladin.AladinPlugin, palmmeteo_stdplugins.cams.CAMSPlugin, palmmeteo_stdplugins.camx.CAMxPlugin, palmmeteo_stdplugins.icon.IconPlugin, palmmeteo_stdplugins.synthetic.SyntheticPlugin, and palmmeteo_stdplugins.wrf.WRFPlugin.

The documentation for this class was generated from the following file:

- palmmeteo/plugins.py